@@ -16,14 +16,12 @@ TZ = {
 	{ 'Africa/Brazzaville', 'WAT-1' },
 	{ 'Africa/Bujumbura', 'CAT-2' },
 	{ 'Africa/Cairo', 'EET-2' },
-	{ 'Africa/Casablanca', 'WET0WEST,M3.5.0,M10.5.0/3' },
 	{ 'Africa/Ceuta', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Africa/Conakry', 'GMT0' },
 	{ 'Africa/Dakar', 'GMT0' },
 	{ 'Africa/Dar es Salaam', 'EAT-3' },
 	{ 'Africa/Djibouti', 'EAT-3' },
 	{ 'Africa/Douala', 'WAT-1' },
-	{ 'Africa/El Aaiun', 'WET0WEST,M3.5.0,M10.5.0/3' },
 	{ 'Africa/Freetown', 'GMT0' },
 	{ 'Africa/Gaborone', 'CAT-2' },
 	{ 'Africa/Harare', 'CAT-2' },
@@ -51,7 +49,7 @@ TZ = {
 	{ 'Africa/Nouakchott', 'GMT0' },
 	{ 'Africa/Ouagadougou', 'GMT0' },
 	{ 'Africa/Porto-Novo', 'WAT-1' },
-	{ 'Africa/Sao Tome', 'WAT-1' },
+	{ 'Africa/Sao Tome', 'GMT0' },
 	{ 'Africa/Tripoli', 'EET-2' },
 	{ 'Africa/Tunis', 'CET-1' },
 	{ 'Africa/Windhoek', 'CAT-2' },
@@ -179,7 +177,7 @@ TZ = {
 	{ 'America/Resolute', 'CST6CDT,M3.2.0,M11.1.0' },
 	{ 'America/Rio Branco', '<-05>5' },
 	{ 'America/Santarem', '<-03>3' },
-	{ 'America/Santiago', '<-04>4<-03>,M8.2.6/24,M5.2.6/24' },
+	{ 'America/Santiago', '<-04>4<-03>,M9.1.6/24,M4.1.6/24' },
 	{ 'America/Santo Domingo', 'AST4' },
 	{ 'America/Sao Paulo', '<-03>3<-02>,M11.1.0/0,M2.3.0/0' },
 	{ 'America/Scoresbysund', '<-01>1<+00>,M3.5.0/0,M10.5.0/1' },
@@ -261,7 +259,7 @@ TZ = {
 	{ 'Asia/Macau', 'CST-8' },
 	{ 'Asia/Magadan', '<+11>-11' },
 	{ 'Asia/Makassar', 'WITA-8' },
-	{ 'Asia/Manila', '<+08>-8' },
+	{ 'Asia/Manila', 'PST-8' },
 	{ 'Asia/Muscat', '<+04>-4' },
 	{ 'Asia/Nicosia', 'EET-2EEST,M3.5.0/3,M10.5.0/4' },
 	{ 'Asia/Novokuznetsk', '<+07>-7' },
@@ -270,9 +268,10 @@ TZ = {
 	{ 'Asia/Oral', '<+05>-5' },
 	{ 'Asia/Phnom Penh', '<+07>-7' },
 	{ 'Asia/Pontianak', 'WIB-7' },
-	{ 'Asia/Pyongyang', 'KST-8:30' },
+	{ 'Asia/Pyongyang', 'KST-9' },
 	{ 'Asia/Qatar', '<+03>-3' },
-	{ 'Asia/Qyzylorda', '<+06>-6' },
+	{ 'Asia/Qostanay', '<+06>-6' },
+	{ 'Asia/Qyzylorda', '<+05>-5' },
 	{ 'Asia/Riyadh', '<+03>-3' },
 	{ 'Asia/Sakhalin', '<+11>-11' },
 	{ 'Asia/Samarkand', '<+05>-5' },
@@ -283,7 +282,7 @@ TZ = {
 	{ 'Asia/Taipei', 'CST-8' },
 	{ 'Asia/Tashkent', '<+05>-5' },
 	{ 'Asia/Tbilisi', '<+04>-4' },
-	{ 'Asia/Tehran', '<+0330>-3:30<+0430>,J80/0,J264/0' },
+	{ 'Asia/Tehran', '<+0330>-3:30<+0430>,J79/24,J263/24' },
 	{ 'Asia/Thimphu', '<+06>-6' },
 	{ 'Asia/Tokyo', 'JST-9' },
 	{ 'Asia/Tomsk', '<+07>-7' },
@@ -358,7 +357,7 @@ TZ = {
 	{ 'Europe/Busingen', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Chisinau', 'EET-2EEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Copenhagen', 'CET-1CEST,M3.5.0,M10.5.0/3' },
-	{ 'Europe/Dublin', 'GMT0IST,M3.5.0/1,M10.5.0' },
+	{ 'Europe/Dublin', 'IST-1GMT0,M10.5.0,M3.5.0/1' },
 	{ 'Europe/Gibraltar', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Guernsey', 'GMT0BST,M3.5.0/1,M10.5.0' },
 	{ 'Europe/Helsinki', 'EET-2EEST,M3.5.0/3,M10.5.0/4' },
@@ -400,7 +399,7 @@ TZ = {
 	{ 'Europe/Vatican', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Vienna', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Vilnius', 'EET-2EEST,M3.5.0/3,M10.5.0/4' },
-	{ 'Europe/Volgograd', '<+03>-3' },
+	{ 'Europe/Volgograd', '<+04>-4' },
 	{ 'Europe/Warsaw', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Zagreb', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Zaporozhye', 'EET-2EEST,M3.5.0/3,M10.5.0/4' },
@@ -421,11 +420,11 @@ TZ = {
 	{ 'Pacific/Bougainville', '<+11>-11' },
 	{ 'Pacific/Chatham', '<+1245>-12:45<+1345>,M9.5.0/2:45,M4.1.0/3:45' },
 	{ 'Pacific/Chuuk', '<+10>-10' },
-	{ 'Pacific/Easter', '<-06>6<-05>,M8.2.6/22,M5.2.6/22' },
+	{ 'Pacific/Easter', '<-06>6<-05>,M9.1.6/22,M4.1.6/22' },
 	{ 'Pacific/Efate', '<+11>-11' },
 	{ 'Pacific/Enderbury', '<+13>-13' },
 	{ 'Pacific/Fakaofo', '<+13>-13' },
-	{ 'Pacific/Fiji', '<+12>-12<+13>,M11.1.0,M1.2.1/147' },
+	{ 'Pacific/Fiji', '<+12>-12<+13>,M11.1.0,M1.2.2/123' },
 	{ 'Pacific/Funafuti', '<+12>-12' },
 	{ 'Pacific/Galapagos', '<-06>6' },
 	{ 'Pacific/Gambier', '<-09>9' },
